@@ -5,5 +5,5 @@ A set of utilities for data & tasks loading, preprocessing, and sampling.
 """
 
 from . import transforms
-from .meta_dataset import MetaDataset
+from .meta_dataset import MetaDataset, UnionMetaDataset, FilteredMetaDataset
 from .task_dataset import TaskDataset, DataDescription
